@@ -8,37 +8,40 @@
 #' @return (character) path to the downloaded SQL database
 #' @details Downloads sql database, cleans up unneeded files, returns path
 #' to sql file
+#' @note The Plant List (TPL) is no longer accessible. If you have a copy of the
+#' sqlite database you can still use the rest of the TPL functions with it. We 
+#' suggest using the World Flora Online (WFO) database as a replacement.
 #' @seealso [tdb_cache]
-#' @examples \dontrun{
+#' @examples 
+#' \dontrun{
 #' # ITIS
-#' # db_download_itis()
-#' # src_itis()
+#' db_download_itis()
+#' src_itis()
 #'
 #' # Plantlist
-#' # db_download_tpl()
-#' # db_download_tpl(overwrite=TRUE) # overwrite - download again
-#' # src_tpl()
+#' db_download_tpl()
+#' src_tpl()
 #'
 #' # COL
-#' # db_download_col()
-#' # src_col()
+#' db_download_col()
+#' src_col()
 #'
 #' # GBIF
-#' # db_download_gbif()
-#' # src_gbif()
+#' db_download_gbif()
+#' src_gbif()
 #'
 #' # NCBI
-#' # db_download_ncbi()
-#' # src_ncbi()
+#' db_download_ncbi()
+#' src_ncbi()
 #'
 #' # Wikidata
-#' # db_download_wikidata()
-#' # db_download_wikidata(overwrite=TRUE) # overwrite - download again
-#' # src_wikidata()
+#' db_download_wikidata()
+#' db_download_wikidata(overwrite=TRUE) # overwrite - download again
+#' src_wikidata()
 #' 
 #' # World Flora Online
-#' # db_download_wfo()
-#' # src_wfo()
+#' db_download_wfo()
+#' src_wfo()
 #' }
 
 #' @export
@@ -125,7 +128,7 @@ db_download_ncbi <- function(verbose = TRUE, overwrite = FALSE) {
   hierarchs <- list()
   # set up the base table with columns 'tax_id', 'ancestor', and 'level', where
   # level is 1 for immediate parent
-  hierarchs[[1]] <- ncbi_nodes[, c('tax_id', 'parent_tax_id')] %>%
+  hierarchs[[1]] <- ncbi_nodes[, c('tax_id', 'parent_tax_id')] |>
     magrittr::set_names(c('tax_id', 'ancestor'))
   hierarchs[[1]]$level <- 1
   # make a child to parent map
@@ -254,10 +257,8 @@ db_download_itis <- function(verbose = TRUE, overwrite = FALSE) {
 
 #' @export
 #' @rdname db_download
-db_download_tpl <- function(verbose = TRUE, overwrite = FALSE) {
-  db_url <- "https://taxize-dbs.s3-us-west-2.amazonaws.com/plantlist.zip" #nolint
-  db_path <- file.path(tdb_cache$cache_path_get(), 'plantlist.zip')
-  db_path_file <- file.path(tdb_cache$cache_path_get(), 'plantlist')
+db_download_tpl <- function(verbose = TRUE, overwrite = FALSE) { 
+  db_path_dir <- file.path(tdb_cache$cache_path_get(), 'tpl')
   final_file <- file.path(tdb_cache$cache_path_get(), 'plantlist.sqlite')
 
   assert(verbose, "logical")
@@ -265,31 +266,19 @@ db_download_tpl <- function(verbose = TRUE, overwrite = FALSE) {
   if (file.exists(final_file) && !overwrite) {
     mssg(verbose, "Database already exists, returning old file")
     return(final_file)
+  } else {
+    stop(
+      "The Plant List (TPL) is no longer accessible. If you have a copy of the
+      sqlite database you can still use the rest of the TPL functions with it. 
+      We suggest using the World Flora Online (WFO) database as a replacement."
+    )
   }
-  unlink(final_file, force = TRUE)
-
-  # make home dir if not already present
-  tdb_cache$mkdir()
-  # download data
-  mssg(verbose, 'downloading...')
-  curl::curl_download(db_url, db_path, quiet = TRUE)
-  # unzip
-  mssg(verbose, 'unzipping...')
-  utils::unzip(db_path, exdir = db_path_file)
-  # move database
-  file.rename(file.path(db_path_file, "plantlist.sqlite"), final_file)
-  # cleanup
-  mssg(verbose, 'cleaning up...')
-  unlink(db_path)
-  unlink(db_path_file, recursive = TRUE)
-  # return path
-  return(final_file)
 }
 
 #' @export
 #' @rdname db_download
 db_download_wfo <- function(verbose = TRUE, overwrite = FALSE) {
-  db_url <- "http://104.198.143.165/files/WFO_Backbone/_WFOCompleteBackbone/WFO_Backbone.zip" #nolint
+  db_url <- "https://zenodo.org/records/10425161/files/_DwC_backbone_R.zip?download=1" #nolint
   db_path <- file.path(tdb_cache$cache_path_get(), 'WFO_Backbone.zip')
   db_path_file <- file.path(tdb_cache$cache_path_get(), 'WFO_Backbone')
   class_file <- file.path(tdb_cache$cache_path_get(), 'WFO_Backbone/classification.csv')
@@ -385,9 +374,10 @@ db_download_wfo <- function(verbose = TRUE, overwrite = FALSE) {
 #' @export
 #' @rdname db_download
 db_download_col <- function(verbose = TRUE, overwrite = FALSE) {
-  db_url <- 'https://taxize-dbs.s3-us-west-2.amazonaws.com/col.zip'
+  db_url <- 'https://api.checklistbank.org/dataset/294826/export.zip?extended=true&format=DwCA'
   db_path <- file.path(tdb_cache$cache_path_get(), 'col.sqlite')
   db_path_file <- file.path(tdb_cache$cache_path_get(), 'col.zip')
+  db_path_dir <- file.path(tdb_cache$cache_path_get(), 'col')
 
   assert(verbose, "logical")
   assert(overwrite, "logical")
@@ -402,10 +392,64 @@ db_download_col <- function(verbose = TRUE, overwrite = FALSE) {
   curl::curl_download(db_url, db_path_file, quiet = TRUE)
 
   mssg(verbose, 'unzipping...')
-  utils::unzip(db_path_file, exdir = tdb_cache$cache_path_get())
+  utils::unzip(db_path_file, exdir = db_path_dir)
+
+  # Convert to SQLite database
+
+  mssg(verbose, 'building SQLite database...')
+  db <- RSQLite::dbConnect(RSQLite::SQLite(), dbname = db_path)
+
+  out <- readr::read_tsv_chunked(
+    paste0(db_path_dir, "/Distribution.tsv"),
+    callback = function(chunk, dummy) {
+      names(chunk) <- gsub("^.*:", "", names(chunk))
+      DBI::dbWriteTable(db, "distribution", chunk, append = T)
+    },
+    chunk_size = 10000,
+    col_types = "cccccc"
+  )
+
+  out <- readr::read_tsv_chunked(
+    paste0(db_path_dir, "/SpeciesProfile.tsv"),
+    callback = function(chunk, dummy) {
+      names(chunk) <- gsub("^.*:", "", names(chunk))
+      DBI::dbWriteTable(db, "speciesprofile", chunk, append = T)
+    },
+    chunk_size = 10000,
+    col_types = "ccccc"
+  )
+
+  out <- readr::read_tsv_chunked(
+    paste0(db_path_dir, "/VernacularName.tsv"),
+    callback = function(chunk, dummy) {
+      names(chunk) <- gsub("^.*:", "", names(chunk))
+      DBI::dbWriteTable(db, "vernacular", chunk, append = T)
+    },
+    chunk_size = 10000,
+    col_types = "ccc"
+  )
+
+  out <- readr::read_tsv_chunked(
+    paste0(db_path_dir, "/Taxon.tsv"),
+    callback = function(chunk, dummy) {
+      names(chunk) <- gsub("^.*:", "", names(chunk))
+      DBI::dbWriteTable(db, "taxa", chunk, append = T)
+    },
+    chunk_size = 10000,
+    col_types = "cccccicccclccccllccccc"
+  )
+
+  # create indices
+  RSQLite::dbExecute(db, 'CREATE UNIQUE INDEX id on taxa (taxonID)')
+  RSQLite::dbExecute(db, 'CREATE INDEX sciname on taxa (scientificName)')
+  RSQLite::dbExecute(db, 'CREATE INDEX parname on taxa (parentNameUsageID)')
+
+  # disconnect
+  RSQLite::dbDisconnect(db)
 
   mssg(verbose, 'cleaning up...')
   unlink(db_path_file)
+  unlink(db_path_dir, recursive = TRUE)
 
   mssg(verbose, 'all done...')
   return(db_path)
@@ -414,9 +458,10 @@ db_download_col <- function(verbose = TRUE, overwrite = FALSE) {
 #' @export
 #' @rdname db_download
 db_download_gbif <- function(verbose = TRUE, overwrite = FALSE) {
-  db_url <- 'https://taxize-dbs.s3-us-west-2.amazonaws.com/gbif.zip'
+  db_url <- "https://hosted-datasets.gbif.org/datasets/backbone/current/backbone.zip"
   db_path <- file.path(tdb_cache$cache_path_get(), 'gbif.sqlite')
-  db_path_file <- file.path(tdb_cache$cache_path_get(), 'gbif.zip')
+  db_path_file <- file.path(tdb_cache$cache_path_get(), 'backbone.zip')
+  db_path_dir <- file.path(tdb_cache$cache_path_get(), 'gbif')
 
   assert(verbose, "logical")
   assert(overwrite, "logical")
@@ -431,10 +476,37 @@ db_download_gbif <- function(verbose = TRUE, overwrite = FALSE) {
   curl::curl_download(db_url, db_path_file, quiet = TRUE)
 
   mssg(verbose, 'unzipping...')
-  utils::unzip(db_path_file, exdir = tdb_cache$cache_path_get())
+  utils::unzip(
+    db_path_file, 
+    exdir = paste0(tdb_cache$cache_path_get(), "/gbif")
+  )
+
+  # Convert to SQLite database
+
+  mssg(verbose, 'building SQLite database...')
+  db <- RSQLite::dbConnect(RSQLite::SQLite(), dbname = db_path)
+
+  out <- vroom::vroom(
+    paste0(tdb_cache$cache_path_get(), "/gbif/Taxon.tsv"),
+    delim = "\t",
+    col_types = "icccccccccccccccccccccc",
+    progress = FALSE
+  )
+
+  DBI::dbWriteTable(db, "gbif", out, append = TRUE, batch_rows = 10000)
+
+  # create indices
+  RSQLite::dbExecute(db, 'CREATE UNIQUE INDEX id on gbif (taxonID)')
+  RSQLite::dbExecute(db, 'CREATE INDEX conname on gbif (canonicalName)')
+  RSQLite::dbExecute(db, 'CREATE INDEX sciname on gbif (scientificName)')
+  RSQLite::dbExecute(db, 'CREATE INDEX parname on gbif (parentNameUsageID)')
+
+  # disconnect
+  RSQLite::dbDisconnect(db)
 
   mssg(verbose, 'cleaning up...')
   unlink(db_path_file)
+  unlink(db_path_dir, recursive = TRUE)
 
   mssg(verbose, 'all done...')
   return(db_path)
