@@ -2,10 +2,6 @@ context("sql_collect")
 
 skip_on_cran()
 
-library(dplyr, quietly = TRUE, warn.conflicts = FALSE)
-library(DBI, quietly = TRUE, warn.conflicts = FALSE)
-library(RSQLite, quietly = TRUE, warn.conflicts = FALSE)
-
 test_that("sql_collect works", {
   # src
   # src <- dplyr::src_sqlite("irisdb.sqlite", create = TRUE)
@@ -21,7 +17,7 @@ test_that("sql_collect works", {
                      'petalwidth', 'species'))
 
   ## with pipe
-  bb <- src %>% sql_collect("select * from iris limit 5")
+  bb <- src |> sql_collect("select * from iris limit 5")
 
   expect_identical(aa, bb)
 
