@@ -15,7 +15,7 @@ test_that("taxa_at", {
   for (i in list(ncbi_1, ncbi_2, itis, wfo_1, wfo_2, gbif_1, gbif_2)) expect_named(i[[1]], c("name", "rank", "id"))
   
   skip_on_ci()
-  col <- taxa_at(c(3960765, 3953606, 3953010), rank = "family", db="col")
+  col <- taxa_at(c("C66T4", "C7ZVH", "TP"), rank = "family", db = "col")
   expect_is(col, "taxa_at")
   expect_is(unclass(col), "list")
   expect_is(col[[1]], "data.frame")
